@@ -1,3 +1,5 @@
+import struct
+
 from datetime import time as Time
 
 import pytest
@@ -112,9 +114,14 @@ def test_broken_pipe_read(con, db_kwargs):
     pid1 = res[0][0]
 
     con.run("select pg_terminate_backend(:v)", v=pid1)
-    with pytest.raises(InterfaceError, match="network error on read"):
+    with pytest.raises(InterfaceError, match="network error"):
         db1.run("select 1")
 
+    try:
+        db1.close()
+    except InterfaceError:
+        pass
+
 
 def test_broken_pipe_unpack(con):
     res = con.run("select pg_backend_pid()")
@@ -139,7 +146,7 @@ def test_broken_pipe_flush(con, db_kwargs):
     try:
         db1.close()
     except InterfaceError as e:
-        assert str(e) == "network error on flush"
+        assert str(e) == "network error"
 
 
 def test_application_name(db_kwargs):
@@ -166,7 +173,8 @@ def test_application_name_integer(db_kwargs):
 
 def test_application_name_bytearray(db_kwargs):
     db_kwargs["application_name"] = bytearray(b"Philby")
-    Connection(**db_kwargs)
+    with Connection(**db_kwargs):
+        pass
 
 
 class PG8000TestException(Exception):
@@ -204,3 +212,9 @@ def test_closed_connection(con):
     con.close()
     with pytest.raises(InterfaceError, match="connection is closed"):
         con.run("VALUES ('hw1'::text)")
+
+
+def test_network_error_on_connect(db_kwargs, mocker):
+    mocker.patch("pg8000.core.ci_unpack", side_effect=struct.error())
+    with pytest.raises(InterfaceError, match="network error"):
+        Connection(**db_kwargs)
